==> xfxbase-2.6.24.tar.gz: lib/XPlayer.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:xcommonwidgets/xcommonwidgets.dart';
import 'package:xfxbase/xfxbase.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'package:intl/intl.dart';

import 'XAppStateBase.dart';
import 'XMainDash_Base.dart';

class XPlayer<T extends XAppStateBase> extends StatefulWidget {
  XPlayer(
    this.liDashBoardIndexesToShow, {
    Key? key,
    this.dataIsNull,
    this.appName,
    this.appVersion,
    this.backGroundColor,
  }) : super(key: key);
  List<int> liDashBoardIndexesToShow;
  static List<XDashboard> liXDashBoard = List<XDashboard>.empty(growable: true);
  bool? dataIsNull;
  String? appName;
  String? appVersion;
  Color? backGroundColor;
  String? clock;
  @override
  _XPlayerState<T> createState() => _XPlayerState<T>();
}

class _XPlayerState<T extends XAppStateBase> extends State<XPlayer<T>> {
  int currentDashIdx = -1;
  int currentPlayerIdx = 0;
  Timer? timerClock;
  bool isActive_XPlayer = true;
  XDashboard? xDashboardActive;
  String? clockUI;
  @override
  void initState() {
    timerClock = Timer.periodic(Duration(seconds: 1), (d) {
      setState(() {
        clockUI = "${DateFormat("HH:mm:ss").format(DateTime.now())}";
      });
    });
    if (widget.liDashBoardIndexesToShow.isNotEmpty) currentDashIdx = widget.liDashBoardIndexesToShow[0];
    super.initState();
  }

  cmd_Play() {
    if (isActive_XPlayer) {
      xDashboardActive?.onTimeOut = null; //non chiamerà un cazzo!
    } else {
      cmd_Next();
    }
    setState(() {
      isActive_XPlayer = isActive_XPlayer.not();
    });
  }

  cmd_Next() {
    currentPlayerIdx++;
    if (currentPlayerIdx >= widget.liDashBoardIndexesToShow.length) currentPlayerIdx = 0;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  cmd_Previous() {
    currentPlayerIdx--;
    if (currentPlayerIdx < 0) currentPlayerIdx = widget.liDashBoardIndexesToShow.length - 1;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  xBuilder_ToolBar() {
    return Container(
        margin: EdgeInsets.only(right: 100, top: 2),
        child: Row(mainAxisSize: MainAxisSize.min, children: [
          isActive_XPlayer
              ? XBtnbase(
                  margin: EdgeInsets.all(5),
                  icon: Icons.skip_previous_outlined,
                  icon_Color: Colors.grey,
                  width: 40,
                  height: 40,
                  backGroundColor: Colors.blue.withAlpha(100),
                )
              : XBtnbase(
                  margin: EdgeInsets.all(5),
                  icon: Icons.skip_previous_outlined,
                  icon_Color: Colors.white,
                  onPressed: () => cmd_Next(),
                  width: 40,
                  height: 40,
                  backGroundColor: Colors.blue.withAlpha(100),
                ),
          XBtnbase(
            margin: EdgeInsets.all(5),
            icon: isActive_XPlayer ? Icons.pause : Icons.play_arrow_outlined,
            icon_Color: isActive_XPlayer ? Colors.white : Colors.orange,
            onPressed: () => cmd_Play(),
            width: 40,
            height: 40,
            backGroundColor: Colors.blue.withAlpha(100),
          ),
          isActive_XPlayer
              ? XBtnbase(
                  margin: EdgeInsets.all(5),
                  icon: Icons.skip_next_outlined,
                  icon_Color: Colors.grey,
                  width: 40,
                  height: 40,
                  backGroundColor: Colors.blue.withAlpha(100),
                )
              : XBtnbase(
                  margin: EdgeInsets.all(5),
                  icon: Icons.skip_next_outlined,
                  icon_Color: Colors.white,
                  onPressed: () => cmd_Previous(),
                  width: 40,
                  height: 40,
                  backGroundColor: Colors.blue.withAlpha(100),
                ),
        ]));
  }

  appBarForDash(String typeOfDash) {
    return XAppBar(
      height: 40,
      backGroundColor: widget.backGroundColor ?? Colors.black,
      title: widget.appName!,
      title_Widget: Row(crossAxisAlignment: CrossAxisAlignment.end, mainAxisSize: MainAxisSize.min, children: [
        Flexible(
            child: Text(widget.appName!.toUpperCase(),
                style: XStyles.xStyleText(
                  colorText: MainDashBase.appColor_AppName,
                  letterSpacing: 1.5,
                  fontSize: 30,
                )))
      ]),
      title_fontSize: 14,
      title_letterSpacing: 1.5,
      leading_Width: 400,
      leading_Widget: Container(
        child: Text(typeOfDash.toUpperCase(), style: XStyles.xStyTextForSubDescr(MainDashBase.appColor_BackGroundLight)),
        margin: EdgeInsets.only(top: 8, left: 8),
      ),
      actions: [
        xBuilder_ToolBar(),
        Container(
            width: 300,
            margin: EdgeInsets.only(right: 10),
            alignment: Alignment.center,
            child: widget.dataIsNull == false
                ? Text("NO CONNESSIONE", style: XStyles.xStyleText(colorText: Colors.red, fontSize: 30)) //
                : Container(child: Text("DASHBOARD v.${widget.appVersion} delle ${clockUI ?? ""}", style: XStyles.xStyTextForTextBase(MainDashBase.appColor_BackGroundLight))))
      ],
    );
  }

//bool wasInWait=false;
  @override
  Widget build(BuildContext context) {
    /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP

    ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
    return Consumer<T>(builder: (context, appState, _) {
      if (appState.dataAreReady) {
        return Scaffold(appBar: appBarForDash("" + XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx).xKey), body: _BuilderTypeOfDash());
      } else {
        ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
        return Scaffold(
            appBar: appBarForDash(XPlayer.liXDashBoard.isEmpty ? " NO PIECES" : "" + XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx).xKey),
            body: MainDashBase.labelForNullDash_Widget ??
                Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                  Container(
                    alignment: Alignment.center,
                    child: Text(MainDashBase.labelForNullDash ?? "... in attesa dei dati ...", style: XStyles.xStyleText(fontSize: 100, colorText: Colors.white)),
                  )
                ]));
      }
    });
  }

  changeScreenFromTimer() {
    currentPlayerIdx++;
    if (currentPlayerIdx >= widget.liDashBoardIndexesToShow.length) currentPlayerIdx = 0;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  _BuilderTypeOfDash() {
    xDashboardActive = XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx);
    if (isActive_XPlayer) {
      if (xDashboardActive?.onTimeOut == null) {
        xDashboardActive?.onTimeOut = (value) {
          changeScreenFromTimer();
        };
      }
    } else {
      xDashboardActive?.onTimeOut = null;
    }
    return xDashboardActive;
  }
}

class XDashboard extends StatefulWidget {
  XDashboard(
    this.idx,
    this.xKey, {
    this.child_RightSide,
    this.child_LeftSide_TOP,
    this.child_LeftSide_MIDDLE,
    this.child_LeftSide_BOTTOM,
    this.onTimeOut,
    this.flex,
    this.timeOfView = 5,
    Key? key,
  }) : super(key: key);

  String xKey = "";
  Widget? child_RightSide;
  Widget? child_LeftSide_TOP;
  Widget? child_LeftSide_MIDDLE;
  Widget? child_LeftSide_BOTTOM;
  int idx = 0;
  int? flex;
  double width_LeftSide = 0;
  double width_RightSide = 0;
  int timeOfView;

  Function(XDashboard)? onTimeOut;

  @override
  _XDashboardState createState() => _XDashboardState();
}

class _XDashboardState extends State<XDashboard> {
  @override
  void initState() {
    super.initState();
  }

  startTimer() {
    var d = Duration(seconds: widget.timeOfView);
    final timer = Timer.periodic(d, (x) {
      x.cancel();
      if (widget.onTimeOut != null) widget.onTimeOut!(widget);
    });
    if (widget.onTimeOut == null) {
      timer.cancel();
    } else {
      timer;
    }
  }

  @override
  Widget build(BuildContext context) {
    startTimer();
    return Row(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Expanded(
            flex: widget.flex ?? 15,
            child: Container(
                child: Column(mainAxisSize: MainAxisSize.min, children: [
              widget.child_LeftSide_TOP != null ? Row(children: [Expanded(child: widget.child_LeftSide_TOP!)]) : Container(),
              widget.child_LeftSide_MIDDLE != null ? Row(children: [Expanded(child: widget.child_LeftSide_MIDDLE!)]) : Container(),
              widget.child_LeftSide_BOTTOM != null ? Row(children: [Expanded(child: widget.child_LeftSide_BOTTOM!)]) : Container(),
            ]))),
        widget.child_RightSide != null ? Expanded(child: widget.child_RightSide!) : Container()
      ],
    );
  }
}

==> xfxbase-2.6.37.tar.gz: lib/XPlayer.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:xcommonwidgets/xcommonwidgets.dart';
import 'package:xfxbase/xfxbase.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'package:intl/intl.dart';

import 'XAppStateBase.dart';
import 'XMainDash_Base.dart';

class XPlayer<T extends XAppStateBase> extends StatefulWidget {
  XPlayer(
    this.liDashBoardIndexesToShow, {
    Key? key,
    this.dataIsNull,
    this.appName,
    this.appVersion,
    this.backGroundColor,
  }) : super(key: key);
  List<int> liDashBoardIndexesToShow;
  static List<XDashboard> liXDashBoard = List<XDashboard>.empty(growable: true);
  bool? dataIsNull;
  String? appName;
  String? appVersion;
  Color? backGroundColor;
  String? clock;
  @override
  _XPlayerState<T> createState() => _XPlayerState<T>();
}

class _XPlayerState<T extends XAppStateBase> extends State<XPlayer<T>> {
  int currentDashIdx = -1;
  int currentPlayerIdx = 0;
  Timer? timerClock;
  bool isActive_XPlayer = true;
  XDashboard? xDashboardActive;
  String? clockUI;
  @override
  void initState() {
    timerClock = Timer.periodic(Duration(seconds: 1), (d) {
      setState(() {
        clockUI = "${DateFormat("HH:mm:ss").format(DateTime.now())}";
      });
    });
    if (widget.liDashBoardIndexesToShow.isNotEmpty) currentDashIdx = widget.liDashBoardIndexesToShow[0];
    super.initState();
  }

  cmd_Play() {
    if (isActive_XPlayer) {
      xDashboardActive?.onTimeOut = null; //non chiamerà un cazzo!
    } else {
      cmd_Next();
    }
    setState(() {
      isActive_XPlayer = isActive_XPlayer.not();
    });
  }

  cmd_Next() {
    currentPlayerIdx++;
    if (currentPlayerIdx >= widget.liDashBoardIndexesToShow.length) currentPlayerIdx = 0;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  cmd_Previous() {
    currentPlayerIdx--;
    if (currentPlayerIdx < 0) currentPlayerIdx = widget.liDashBoardIndexesToShow.length - 1;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  xBuilder_ToolBar() {
    return Container(
        margin: EdgeInsets.only(right: 100, top: 2),
        child: Row(mainAxisSize: MainAxisSize.min, children: [
          isActive_XPlayer
              ? XBtnbase(
                  margin: EdgeInsets.all(5),
                  icon: Icons.skip_previous_outlined,
                  icon_Color: Colors.grey,
                  width: 40,
                  height: 40,
                  backGroundColor: Colors.blue.withAlpha(100),
                )
              : XBtnbase(
                  margin: EdgeInsets.all(5),
                  icon: Icons.skip_previous_outlined,
                  icon_Color: Colors.white,
                  onPressed: () => cmd_Next(),
                  width: 40,
                  height: 40,
                  backGroundColor: Colors.blue.withAlpha(100),
                ),
          XBtnbase(
            margin: EdgeInsets.all(5),
            icon: isActive_XPlayer ? Icons.pause : Icons.play_arrow_outlined,
            icon_Color: isActive_XPlayer ? Colors.white : Colors.orange,
            onPressed: () => cmd_Play(),
            width: 40,
            height: 40,
            backGroundColor: Colors.blue.withAlpha(100),
          ),
          isActive_XPlayer
              ? XBtnbase(
                  margin: EdgeInsets.all(5),
                  icon: Icons.skip_next_outlined,
                  icon_Color: Colors.grey,
                  width: 40,
                  height: 40,
                  backGroundColor: Colors.blue.withAlpha(100),
                )
              : XBtnbase(
                  margin: EdgeInsets.all(5),
                  icon: Icons.skip_next_outlined,
                  icon_Color: Colors.white,
                  onPressed: () => cmd_Previous(),
                  width: 40,
                  height: 40,
                  backGroundColor: Colors.blue.withAlpha(100),
                ),
        ]));
  }

  appBarForDash(String typeOfDash) {
    return XAppBar(
      height: 40,
      backGroundColor: widget.backGroundColor ?? Colors.black,
      title: widget.appName!,
      title_Widget: Row(crossAxisAlignment: CrossAxisAlignment.end, mainAxisSize: MainAxisSize.min, children: [
        Flexible(
            child: Text(widget.appName!.toUpperCase(),
                style: XStyles.xStyleText(
                  colorText: MainDashBase.appColor_AppName,
                  letterSpacing: 1.5,
                  fontSize: 30,
                )))
      ]),
      title_fontSize: 14,
      title_letterSpacing: 1.5,
      leading_Width: 400,
      leading_Widget: Container(
        child: Text(typeOfDash.toUpperCase(), style: XStyles.xStyTextForSubDescr(textColor: MainDashBase.appColor_BackGroundLight)),
        margin: EdgeInsets.only(top: 8, left: 8),
      ),
      actions: [
        xBuilder_ToolBar(),
        Container(
            width: 300,
            margin: EdgeInsets.only(right: 10),
            alignment: Alignment.center,
            child: widget.dataIsNull == false
                ? Text("NO CONNESSIONE", style: XStyles.xStyleText(colorText: Colors.red, fontSize: 30)) //
                : Container(child: Text("DASHBOARD v.${widget.appVersion} delle ${clockUI ?? ""}", style: XStyles.xStyTextForTextBase(textColor: MainDashBase.appColor_BackGroundLight))))
      ],
    );
  }

//bool wasInWait=false;
  @override
  Widget build(BuildContext context) {
    /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP

    ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
    return Consumer<T>(builder: (context, appState, _) {
      if (appState.dataAreReady) {
        return Scaffold(appBar: appBarForDash("" + XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx).xKey), body: _BuilderTypeOfDash());
      } else {
        ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
        return Scaffold(
            appBar: appBarForDash(XPlayer.liXDashBoard.isEmpty ? " NO PIECES" : "" + XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx).xKey),
            body: MainDashBase.labelForNullDash_Widget ??
                Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                  Container(
                    alignment: Alignment.center,
                    child: Text(MainDashBase.labelForNullDash ?? "... in attesa dei dati ...", style: XStyles.xStyleText(fontSize: 100, colorText: Colors.white)),
                  )
                ]));
      }
    });
  }

  changeScreenFromTimer() {
    currentPlayerIdx++;
    if (currentPlayerIdx >= widget.liDashBoardIndexesToShow.length) currentPlayerIdx = 0;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  _BuilderTypeOfDash() {
    xDashboardActive = XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx);
    if (isActive_XPlayer) {
      if (xDashboardActive?.onTimeOut == null) {
        xDashboardActive?.onTimeOut = (value) {
          changeScreenFromTimer();
        };
      }
    } else {
      xDashboardActive?.onTimeOut = null;
    }
    return xDashboardActive;
  }
}

class XDashboard extends StatefulWidget {
  XDashboard(
    this.idx,
    this.xKey, {
    this.child_RightSide,
    this.child_LeftSide_TOP,
    this.child_LeftSide_MIDDLE,
    this.child_LeftSide_BOTTOM,
    this.onTimeOut,
    this.flex,
    this.timeOfView = 5,
    Key? key,
  }) : super(key: key);

  String xKey = "";
  Widget? child_RightSide;
  Widget? child_LeftSide_TOP;
  Widget? child_LeftSide_MIDDLE;
  Widget? child_LeftSide_BOTTOM;
  int idx = 0;
  int? flex;
  double width_LeftSide = 0;
  double width_RightSide = 0;
  int timeOfView;

  Function(XDashboard)? onTimeOut;

  @override
  _XDashboardState createState() => _XDashboardState();
}

class _XDashboardState extends State<XDashboard> {
  @override
  void initState() {
    super.initState();
  }

  startTimer() {
    var d = Duration(seconds: widget.timeOfView);
    final timer = Timer.periodic(d, (x) {
      x.cancel();
      if (widget.onTimeOut != null) widget.onTimeOut!(widget);
    });
    if (widget.onTimeOut == null) {
      timer.cancel();
    } else {
      timer;
    }
  }

  @override
  Widget build(BuildContext context) {
    startTimer();
    return Row(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Expanded(
            flex: widget.flex ?? 15,
            child: Container(
                child: Column(mainAxisSize: MainAxisSize.min, children: [
              widget.child_LeftSide_TOP != null ? Row(children: [Expanded(child: widget.child_LeftSide_TOP!)]) : Container(),
              widget.child_LeftSide_MIDDLE != null ? Row(children: [Expanded(child: widget.child_LeftSide_MIDDLE!)]) : Container(),
              widget.child_LeftSide_BOTTOM != null ? Row(children: [Expanded(child: widget.child_LeftSide_BOTTOM!)]) : Container(),
            ]))),
        widget.child_RightSide != null ? Expanded(child: widget.child_RightSide!) : Container()
      ],
    );
  }
}
